# -*- coding: utf-8 -*-

"""
Regarding to the main documentation you find here all the stuff which is related to the reader layer. This
layer is part of the core server application. It is addressed directly by the processor. Its main task is to
call the user configured sources and read all the necessary records from them. This is the lowest core layer.

.. note:: This layer is not meant to be adapted in normal.
"""
